[commit: ghc] master: Fix typo: Superclases -> Superclasses (00053ee)

git at git.haskell.org git at git.haskell.org
Fri Apr 29 14:43:41 UTC 2016


Repository : ssh://git@git.haskell.org/ghc

On branch  : master
Link       : http://ghc.haskell.org/trac/ghc/changeset/00053ee6f450c4503c25ed9ba33089d991e2a04b/ghc

>---------------------------------------------------------------

commit 00053ee6f450c4503c25ed9ba33089d991e2a04b
Author: Bartosz Nitka <niteria at gmail.com>
Date:   Fri Apr 29 07:46:24 2016 -0700

    Fix typo: Superclases -> Superclasses


>---------------------------------------------------------------

00053ee6f450c4503c25ed9ba33089d991e2a04b
 compiler/typecheck/TcInstDcls.hs | 4 ++--
 compiler/typecheck/TcRnTypes.hs  | 2 +-
 compiler/typecheck/TcSimplify.hs | 4 ++--
 3 files changed, 5 insertions(+), 5 deletions(-)

diff --git a/compiler/typecheck/TcInstDcls.hs b/compiler/typecheck/TcInstDcls.hs
index 8554796..483d322 100644
--- a/compiler/typecheck/TcInstDcls.hs
+++ b/compiler/typecheck/TcInstDcls.hs
@@ -952,7 +952,7 @@ Notice that
 
 ************************************************************************
 *                                                                      *
-      Type-checking superclases
+      Type-checking superclasses
 *                                                                      *
 ************************************************************************
 -}
@@ -1115,7 +1115,7 @@ add (Super (Fam a)) to the context of (i3).
 Note [Solving superclass constraints]
 ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 How do we ensure that every superclass witness is generated by
-one of (sc1) (sc2) or (sc3) in Note [Recursive superclases].
+one of (sc1) (sc2) or (sc3) in Note [Recursive superclasses].
 Answer:
 
   * Superclass "wanted" constraints have CtOrigin of (ScOrigin size)
diff --git a/compiler/typecheck/TcRnTypes.hs b/compiler/typecheck/TcRnTypes.hs
index f3aef11..2172cd8 100644
--- a/compiler/typecheck/TcRnTypes.hs
+++ b/compiler/typecheck/TcRnTypes.hs
@@ -1812,7 +1812,7 @@ isPendingScDict _ = Nothing
 superClassesMightHelp :: Ct -> Bool
 -- ^ True if taking superclasses of givens, or of wanteds (to perhaps
 -- expose more equalities or functional dependencies) might help to
--- solve this constraint.  See Note [When superclases help]
+-- solve this constraint.  See Note [When superclasses help]
 superClassesMightHelp ct
   = isWantedCt ct && not (is_ip ct)
   where
diff --git a/compiler/typecheck/TcSimplify.hs b/compiler/typecheck/TcSimplify.hs
index 58ed3ca..bb17fd7 100644
--- a/compiler/typecheck/TcSimplify.hs
+++ b/compiler/typecheck/TcSimplify.hs
@@ -446,7 +446,7 @@ tcCheckSatisfiability given_ids
        ; (res, _ev_binds) <- runTcS $
              do { traceTcS "checkSatisfiability {" (ppr given_ids)
                 ; given_cts <- mkGivensWithSuperClasses given_loc (bagToList given_ids)
                      -- See Note [Superclases and satisfiability]
                 ; insols <- solveSimpleGivens given_cts
                 ; insols <- try_harder insols
                 ; traceTcS "checkSatisfiability }" (ppr insols)
@@ -465,7 +465,7 @@ tcCheckSatisfiability given_ids
            ; new_given <- makeSuperClasses pending_given
            ; solveSimpleGivens new_given }
 
-{- Note [Superclases and satisfiability]
+{- Note [Superclasses and satisfiability]
 ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 Expand superclasses before starting, because (Int ~ Bool), has
 (Int ~~ Bool) as a superclass, which in turn has (Int ~N# Bool)
@@ -446,7 +446,7 @@ tcCheckSatisfiability given_ids
              do { traceTcS "checkSatisfiability {" (ppr given_ids)
                 ; given_cts <- mkGivensWithSuperClasses given_loc (bagToList given_ids)
-                     -- See Note [Superclases and satisfiability]
+                     -- See Note [Superclasses and satisfiability]
                 ; insols <- solveSimpleGivens given_cts
                 ; insols <- try_harder insols



More information about the ghc-commits mailing list